<?php
/**
 * Theme Ostrich Customizer
 *
 * @package Music Center
 */

/**
 * Get all the default values of the theme mods.
 */
function music_center_get_default_mods() {
	$music_center_default_mods = array(
		// Footer copyright
		'music_center_copyright_txt' => esc_html__( 'Copyright &copy; [the-year] [site-link]  |  ', 'music-center' ),
		'music_center_power_by_txt'	=> sprintf( esc_html__( 'Theme: %1$s by %2$s.', 'music-center' ), 'Music Center', '<a href="' . esc_url( 'http://themeostrich.com/' ) . '">Theme Ostrichs</a>' ),
	);

	return apply_filters( 'music_center_default_mods', $music_center_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function music_center_customize_register( $wp_customize ) {

	// Custom Controller
	require get_parent_theme_file_path( '/inc/customizer/custom-controller.php' );

	$default = music_center_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'music_center_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'music_center_customize_partial_blogdescription',
		) );
	}

	//Color Panel

	// Header tagline color setting
	$wp_customize->add_setting(	
		'music_center_header_tagline',
		array(
			'sanitize_callback' => 'music_center_sanitize_hex_color',
			'default' => '#fff',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'music_center_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'music-center' ),
			)
		)
	);

	// Header text display setting
	$wp_customize->add_setting(	
		'music_center_header_text_display',
		array(
			'sanitize_callback' => 'music_center_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'music_center_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'music-center' ),
		)
	);

	// Your latest posts title setting
	$wp_customize->add_setting(	
		'music_center_your_latest_posts_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Blogs', 'music-center' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'music_center_your_latest_posts_title',
		array(
			'section'		=> 'static_front_page',
			'label'			=> esc_html__( 'Title:', 'music-center' ),
			'active_callback' => 'music_center_is_latest_posts'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'music_center_your_latest_posts_title', 
		array(
	        'selector'            => '.home.blog #page-header .page-title',
			'render_callback'     => 'music_center_your_latest_posts_partial_title',
    	) 
    );

    $wp_customize->add_setting( 'music_center_enable_content', array(
		'sanitize_callback'   => 'music_center_sanitize_checkbox',
		'default'             => false,
	) );

	$wp_customize->add_control( 'music_center_enable_content', array(
		'label'       	=> esc_html__( 'Enable Content', 'music-center' ),
		'description' 	=> esc_html__( 'Check to enable content on static front page only.', 'music-center' ),
		'section'     	=> 'static_front_page',
		'type'        	=> 'checkbox',
	) );


	/**
	 * 
	 * Front Section
	 * 
	 */ 

	// Home sections panel
	$wp_customize->add_panel(
		'music_center_home_panel',
		array(
			'title' => esc_html__( 'Homepage Options', 'music-center' ),
			'priority' => 105
		)
	);

	//slider
    require get_parent_theme_file_path( '/inc/customizer/homepage/slider.php' );
    
	//music-player
    require get_parent_theme_file_path( '/inc/customizer/homepage/music-player.php' );

    //about
	require get_parent_theme_file_path( '/inc/customizer/homepage/about.php' );

    //release
	require get_parent_theme_file_path( '/inc/customizer/homepage/release.php' );

	//video
    require get_parent_theme_file_path( '/inc/customizer/homepage/video.php' );

	//latest-albums
    require get_parent_theme_file_path( '/inc/customizer/homepage/latest-albums.php' );

    //review
    require get_parent_theme_file_path( '/inc/customizer/homepage/review.php' );

    //team
    require get_parent_theme_file_path( '/inc/customizer/homepage/team.php' );

 	//subscription
    require get_parent_theme_file_path( '/inc/customizer/homepage/subscription.php' );

	//recent-news
    require get_parent_theme_file_path( '/inc/customizer/homepage/recent-news.php' );

    // theme options
	$wp_customize->add_panel(
		'music_center_general_panel',
		array(
			'title' => esc_html__( 'Theme Options', 'music-center' ),
			'priority' => 107
		)
	);

	require get_parent_theme_file_path( '/inc/customizer/theme-options/general-setting.php' );

	require get_parent_theme_file_path( '/inc/customizer/theme-options/layout.php' );

	require get_parent_theme_file_path( '/inc/customizer/theme-options/archive.php' );

	require get_parent_theme_file_path( '/inc/customizer/theme-options/footer.php' );

	/**
	 * Reset all settings
	 */
	// Reset settings section
	$wp_customize->add_section(
		'music_center_reset_sections',
		array(
			'title' => esc_html__( 'Reset all', 'music-center' ),
			'description' => esc_html__( 'Reset all settings to default.', 'music-center' ),
			'panel' => 'music_center_general_panel',
		)
	);

	// Reset sortable order setting
	$wp_customize->add_setting(
		'music_center_reset_settings',
		array(
			'sanitize_callback' => 'music_center_sanitize_checkbox',
			'default' => false,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'music_center_reset_settings',
		array(
			'section'		=> 'music_center_reset_sections',
			'label'			=> esc_html__( 'Reset all settings?', 'music-center' ),
			'type'			=> 'checkbox',
		)
	);
}
add_action( 'customize_register', 'music_center_customize_register' );


// Sanitize Callback
require get_parent_theme_file_path( '/inc/customizer/sanitize-callback.php' );

// active Callback
require get_parent_theme_file_path( '/inc/customizer/active-callback.php' );

// Partial Refresh
require get_parent_theme_file_path( '/inc/customizer/partial-refresh.php' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function music_center_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function music_center_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function music_center_customize_preview_js() {
	wp_enqueue_script( 'music-center-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'music_center_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function music_center_customize_control_js() {


	wp_enqueue_style( 'music-center-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'music-center-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'music-center' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'music-center' ),
	);

	wp_localize_script( 'music-center-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'music_center_customize_control_js' );
