<?php
/**
* Template part for displaying front page introduction.
*
* @package Music Center
*/

// Get the content type.
$release = get_theme_mod( 'music_center_release', 'disable' );
// Bail if the section is disabled.
if ( 'disable' === $release ) {
    return;
}
$section_title    = get_theme_mod( 'music_center_release_title', __( 'Music is composed and performed!!', 'music-center') ) ;
$sub_title    = get_theme_mod( 'music_center_release_sub_title', __( 'Release', 'music-center') ) ;
$get_content = music_center_get_section_content( 'release', $release, 1  );

?>

<div id="release" class="relative pt">
    <div class="container">
        <div class="section-header">
            <?php if( !empty( $sub_title ) ): ?>
                <p class="section-subtitle"><?php echo esc_html( $sub_title ); ?></p>
            <?php endif;

            if( !empty( $section_title ) ):

                ?>
                <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <?php endif; ?>
        </div>

        <?php foreach ( $get_content as $content ): ?>
            <div class="section-content col-2">
                <article>
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( get_the_post_thumbnail_url( $content['id'] ) ) ; ?>');"></div>
                </article>

                <article>
                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>
                        <div class="entry-content">
                            <p><?php echo esc_html( wp_trim_words( $content['content'], 45 ) ); ?></p>
                        </div><!-- .entry-content -->

                        <?php 

                        $release_playlist = ! empty( get_theme_mod('music_center_release_playlist') ) ? get_theme_mod('music_center_release_playlist') : array();

                        $release_playlist = implode(',', $release_playlist);

                        if( !empty( $release_playlist ) ):
                            ?>

                            <div class="playlist-wrapper">

                                <div class="wp-playlist-tracks">
                                    <div class="wp-playlist-item">

                                        <?php 
                                        $release_playlist = '[playlist type="audio" ids="' . $release_playlist . '" style="light"]';
                                        echo do_shortcode( wp_kses_post( $release_playlist ) );  
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>

                    </div><!-- .entry-container -->
                </article>
            </div><!-- .section-content -->

        <?php endforeach; ?>

    </div><!-- .wrapper -->
</div><!-- #about-us -->